.. Django Simple Email Auth documentation master file, created by
   sphinx-quickstart on Wed Sep 18 20:21:36 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   templates
   changelog-proxy


.. include:: ../README.rst
